==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/PersistenceParser__24LongHandlerCreator.h <==
// class gnu.java.beans.decoder.PersistenceParser$LongHandlerCreator

// class file dependencies
// @dep_class 161e1d66b2b4a78c gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator_H_
#define _JC_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_PersistenceParser$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_refs	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$refs	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$object	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$object;

typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vmethods	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtable	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtype	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$method$_init$abe75c23fad35364(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$object *, struct _jc_gnu_java_beans_decoder_PersistenceParser$object *);

// Virtual methods
extern struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object *_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$method$createHandler$5a0dc6a0283274e0(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$method_info$createHandler$5a0dc6a0283274e0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vmethods {
	struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object	*(*createHandler$5a0dc6a0283274e0)(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vmethods	gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_refs {
	struct _jc_gnu_java_beans_decoder_PersistenceParser$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$refs {
    _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_refs	gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_nonrefs	gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$object {
	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtype _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/PersistenceParser__24LongHandlerCreator.h <==
// class gnu.java.beans.decoder.PersistenceParser$LongHandlerCreator

// class file dependencies
// @dep_class ec1129c075ecf45 gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator_H_
#define _JC_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_PersistenceParser$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_refs	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$refs	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$object	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$object;

typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vmethods	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtable	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtype	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$method$_init$abe75c23fad35364(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$object *, struct _jc_gnu_java_beans_decoder_PersistenceParser$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object *_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$method$createHandler$5a0dc6a0283274e0(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$method_info$createHandler$5a0dc6a0283274e0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vmethods {
	struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object	*(*createHandler$5a0dc6a0283274e0)(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vmethods	gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_refs {
	struct _jc_gnu_java_beans_decoder_PersistenceParser$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$refs {
    _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_refs	gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$sub_nonrefs	gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$object {
	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$vtype _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PersistenceParser__24LongHandlerCreator_H_ */
